@@ -4,6 +4,8 @@ ARC="$1"
 DIR="`basename $ARC .tar.bz2`"
 shift
 
+GPGKEY=0D1099BA
+
 mkdir $DIR
 tar -cf - "$@" |tar -xf - -C $DIR
 tar -cjf $ARC $DIR
@@ -11,7 +13,7 @@ rm -fr $DIR
 
 if [ "$USER" = "kj" ]
 then
-    if gpg -u D218DF91 -b $ARC
+    if gpg -u $GPGKEY -b $ARC
     then
         scp $ARC* yanestra@dl.sv.gnu.org:/releases/peng4/
     else
